## How to contribute to coffea

#### **Did you find a bug?**

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/CoffeaTeam/coffea/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/CoffeaTeam/coffea/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.

#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

* Before submitting, please run `python setup.py flake8` and `python setup.py pytest`, to ensure you follow our formatting conventions and do not break any existing code. Furthermore, we require that any newly contributed code does not reduce the current code coverage of the repository. Please make sure your test your code as thoroughly as is needed.

#### **Did you fix whitespace, format code, or make a purely cosmetic patch?**

Changes that are cosmetic in nature and do not add anything substantial to the stability, functionality, or testability of coffea will generally not be accepted.

#### **Do you intend to add a new feature or change an existing one?**

* Suggest your change in the [cms-coffea mailing list](cms-coffea@cern.ch) and start writing code.

* Do not open an issue on GitHub until you have collected positive feedback about the change. GitHub issues are primarily intended for bug reports and fixes.

#### **Do you have questions about the source code?**

* Ask any question about how to use coffea in the [coffea iris-hep slack channel](https://iris-hep.slack.com).

#### **Do you want to contribute to the coffea documentation?**

* Please read [Contributing to the coffea documentation](COMING SOON).

coffea is a HEP community and volunteer effort. We encourage you to pitch in and [join the team](mailto:cms-coffea@cern.ch)!

Thanks! :coffee: :coffee: :coffee:

Coffea Team
